import "./tasks/benchmark.wdl" as benchmark
import "./tasks/mendelian.wdl" as mendelian
import "./tasks/merge_mendelian.wdl" as merge_mendelian
import "./tasks/quartet_mendelian.wdl" as quartet_mendelian
import "./tasks/merge_family.wdl" as merge_family


workflow {{ project_name }} {

	File LCL5
	File LCL6
	File LCL7
	File LCL8

	String BENCHMARKdocker
	String MENDELIANdocker
	String DIYdocker


	String fasta
	File ref_dir

	File benchmarking_dir
	File rename

	String project

	String disk_size
	String BIGcluster_config
	String SMALLcluster_config

	call benchmark.benchmark as LCL5benchmark {
		input:
		vcf=LCL5,
		benchmarking_dir=benchmarking_dir,
		ref_dir=ref_dir,
		fasta=fasta,
		docker=BENCHMARKdocker,
		cluster_config=BIGcluster_config,
		disk_size=disk_size,
	}

	call benchmark.benchmark as LCL6benchmark {
		input:
		vcf=LCL6,
		benchmarking_dir=benchmarking_dir,
		ref_dir=ref_dir,
		fasta=fasta,
		docker=BENCHMARKdocker,
		cluster_config=BIGcluster_config,
		disk_size=disk_size,
	}

	call benchmark.benchmark as LCL7benchmark {
		input:
		vcf=LCL7,
		benchmarking_dir=benchmarking_dir,
		ref_dir=ref_dir,
		fasta=fasta,
		docker=BENCHMARKdocker,
		cluster_config=BIGcluster_config,
		disk_size=disk_size,
	}	

	call benchmark.benchmark as LCL8benchmark {
		input:
		vcf=LCL8,
		benchmarking_dir=benchmarking_dir,
		ref_dir=ref_dir,
		fasta=fasta,
		docker=BENCHMARKdocker,
		cluster_config=BIGcluster_config,
		disk_size=disk_size,
	}

	call merge_family.merge_family as merge_family {
		input:
		LCL5_vcf_gz=LCL5benchmark.rtg_vcf,
		LCL5_vcf_idx=LCL5benchmark.rtg_vcf_index,
		LCL6_vcf_gz=LCL6benchmark.rtg_vcf,
		LCL6_vcf_idx=LCL6benchmark.rtg_vcf_index,
		LCL7_vcf_gz=LCL7benchmark.rtg_vcf,
		LCL7_vcf_idx=LCL7benchmark.rtg_vcf_index,
		LCL8_vcf_gz=LCL8benchmark.rtg_vcf,
		LCL8_vcf_idx=LCL8benchmark.rtg_vcf,
		rename=rename,
		project=project,
		docker=BENCHMARKdocker,
		cluster_config=SMALLcluster_config,
		disk_size=disk_size,
	}

	call mendelian.mendelian as mendelian {
		input:
		family_vcf=merge_family.merged_vcf,
		ref_dir=ref_dir,
		fasta=fasta,
		docker=MENDELIANdocker,
		cluster_config=BIGcluster_config,
		disk_size=disk_size		
	}

	call merge_mendelian.merge_mendelian as merge_mendelian {
		input:
		D5_trio_vcf=mendelian.D5_trio_vcf,
		D6_trio_vcf=mendelian.D6_trio_vcf,
		family_vcf=merge_family.merged_vcf,
		docker=DIYdocker,
		cluster_config=SMALLcluster_config,
		disk_size=disk_size
	}

	call quartet_mendelian.quartet_mendelian as quartet_mendelian {
		input:
		project_mendelian_summary=merge_mendelian.project_mendelian_summary,
		project=project,
		docker=DIYdocker,
		cluster_config=SMALLcluster_config,
		disk_size=disk_size
	}
}


